@@ -2,7 +2,8 @@ package Module::CPANTS::Kwalitee::Distros;
 use warnings;
 use strict;
 
-our $VERSION = '0.90_01';
+our $VERSION = '0.93_01';
+$VERSION = eval $VERSION; ## no critic
 
 sub order { 800 }
 
@@ -66,27 +67,6 @@ Defines the order in which Kwalitee tests should be run.
 
 Returns the Kwalitee Indicators datastructure.
 
-=over
-
-=item * distributed_by_debian
-
-True if the module (package) is repackaged by the Debian-Perl team and 
-you can install it using the package management system of Debian.
-
-=item * latest_version_distributed_by_debian
-
-True if the latest version of the module (package) is repackaged by Debian
-
-=item * has_no_bugs_reported_in_debian
-
-True for if the module is distributed by Debian and no bugs were reported.
-
-=item * has_no_patches_in_debian
-
-True for if the module is distributed by Debian and no patches applied.
-
-=back
-
 =head1 Caveats
 
 CPAN_dist, the name of CPAN distribution is inferred from the download location,
@@ -109,7 +89,7 @@ CPANTS does not yet handle the second issue.
 
 Basic homepage: http://packages.debian.org/src:$pkgname
 
-Detalied homepage: http://packages.qa.debian.org/$pkgname
+Detailed homepage: http://packages.qa.debian.org/$pkgname
 
 Bugs report: http://bugs.debian.org/src:$pkgname
 
